package com.fzm.common.mq;

import com.alibaba.fastjson.JSON;
import com.fzm.common.entity.Notify;
import lombok.RequiredArgsConstructor;
import org.springframework.amqp.core.AmqpTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * @author wt
 * @date 2022/3/7
 */
@Component
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class NotifyPublisher {
    private final AmqpTemplate amqpTemplate;

    public void sendNotify(Notify notify) {
        notify.setType(1);
        notify.setState(1);
        notify.setDelete(0);
        amqpTemplate.convertAndSend(NotifyConfig.NOTIFY_QUEUE, JSON.toJSONString(notify));
    }

    public void personAuthSuccessNotify(Integer uid) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("实名认证");
        notify.setSummary("认证成功");
        notify.setContent("恭喜您，您已完成实名认证");
        sendNotify(notify);
    }

    public void personAuthFailNotify(Integer uid, String result) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("实名认证");
        notify.setSummary("认证失败");
        notify.setContent("恭喜您，您的实名认证未通过。原因：" + result);
        sendNotify(notify);
    }

    public void copyrightApplyRejectNotify(Integer uid, String reason) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("版权申请");
        notify.setSummary("一幕影链核验失败");
        notify.setContent("很抱歉，您的版权申请未通过一幕影链的核验。原因：" + reason);
        sendNotify(notify);
    }

    public void copyrightApplyPassNotify(Integer uid) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("版权申请");
        notify.setSummary("一幕影链核验成功");
        notify.setContent("您好，您的版权申请已通过一幕影链的核验，已提交湖北版权保护中心。请耐心等待审核结果。");
        sendNotify(notify);
    }

    public void copyrightApplySuccessNotify(Integer uid) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("版权申请");
        notify.setSummary("版权局审核成功");
        notify.setContent("您好，您的版权申请已通过湖北版权保护中心的审核，可以在我的-版权申请中查看版权。");
        sendNotify(notify);
    }

    public void copyrightApplyFailNotify(Integer uid, String reason) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("版权申请");
        notify.setSummary("版权局审核失败");
        notify.setContent("很抱歉，您的版权申请未通过湖北版权保护中心的审核。原因：" + reason);
        sendNotify(notify);
    }

    public void nftSuccessNotify(Integer uid, String nftName) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("数字藏品铸造");
        notify.setSummary("铸造成功");
        notify.setContent("恭喜您，您的数字藏品《" + nftName + "》已经铸造成功，可以在我的-我的数字藏品查看。");
        sendNotify(notify);
    }

    public void nftFailNotify(Integer uid, String nftName, String reason) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("数字藏品铸造");
        notify.setSummary("铸造失败");
        notify.setContent("很抱歉，您的数字藏品《" + nftName + "》铸造失败。原因：" + reason);
        sendNotify(notify);
    }

    public void nftOutNotify(Integer uid, String nftName) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("数字藏品转让");
        notify.setSummary("转出成功");
        notify.setContent("恭喜您，您的数字藏品《" + nftName + "》已成功转出。");
        sendNotify(notify);
    }

    public void nftInNotify(Integer uid, String nftName) {
        Notify notify = new Notify();
        notify.setUid(uid);
        notify.setTitle("数字藏品转让");
        notify.setSummary("转入");
        notify.setContent("您好，您的账户成功转入一个数字藏品《" + nftName + "》，可以在我的-我的数字藏品查看。");
        sendNotify(notify);
    }
}
