package com.fzm.common.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fzm.common.entity.CopyrightLog;
import com.fzm.common.enums.CopyrightLogType;
import com.fzm.common.interceptor.LoginUserInfo;
import com.fzm.common.mapper.CopyrightLogMapper;
import com.fzm.common.service.CopyrightLogService;
import lombok.RequiredArgsConstructor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;
import java.util.List;

/**
 * @author wt
 * @date 2022/5/24
 */
@Service
@RequiredArgsConstructor(onConstructor = @__(@Autowired))
public class CopyrightLogServiceImpl extends ServiceImpl<CopyrightLogMapper, CopyrightLog> implements CopyrightLogService {

    @Override
    public void save(Integer cid, CopyrightLogType copyrightLogType, String opInfo) {
        CopyrightLog copyrightLog = new CopyrightLog();
        copyrightLog.setCopyrightId(cid);
        copyrightLog.setCopyrightId(copyrightLogType.getId());
        copyrightLog.setOpType(copyrightLogType.getType());
        copyrightLog.setOpInfo(opInfo);
        copyrightLog.setOpUserId(LoginUserInfo.getLoginUser().getUserId());
        copyrightLog.setOpUserName(LoginUserInfo.getLoginUser().getUsername());
        copyrightLog.setOpTime(new Date());

        save(copyrightLog);
    }

    @Override
    public void saveTask(Integer cid, Integer typeId, String opInfo) {
        CopyrightLogType logType = CopyrightLogType.getById(typeId);
        if (logType == null) {
            return;
        }

        CopyrightLog copyrightLog = new CopyrightLog();
        copyrightLog.setCopyrightId(cid);
        copyrightLog.setCopyrightId(logType.getId());
        copyrightLog.setOpType(logType.getType());
        copyrightLog.setOpInfo(opInfo);
        copyrightLog.setOpUserId(0);
        copyrightLog.setOpUserName("版权局");
        copyrightLog.setOpTime(new Date());

        save(copyrightLog);
    }

    @Override
    public CopyrightLog selectByIdAndType(Integer cid, Integer typeId) {
        QueryWrapper<CopyrightLog> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("copyright_id", cid);
        queryWrapper.eq("op_type_id", typeId);
        return getOne(queryWrapper);
    }

    @Override
    public List<CopyrightLog> logs(Integer cid) {
        QueryWrapper<CopyrightLog> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("copyright_id", cid);
        return list(queryWrapper);
    }
}
